@@ -5,8 +5,8 @@ package org.gcube.portlets.user.td.widgetcommonevent.client.type;
 
 /**
  * 
- * @author "Giancarlo Panichi" 
- * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ * @author Giancarlo Panichi 
+ * 
  *
  */
 public enum ChangeTableRequestType {
@@ -37,5 +37,6 @@ public enum ChangeTableRequestType {
 	DOWNSCALECSQUARE,
 	TASKRESUME,
 	TASKRESUBMIT,
-	STATISTICALOPERATION;
+	STATISTICALOPERATION,
+	RULESONCOLUMNAPPLY;
 }
